schemetools.SchemeMoment
========================

.. abjad-lineage:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment

.. autoclass:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.duration
   :noindex:

.. autoattribute:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.force_quotes
   :noindex:

.. autoattribute:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__eq__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__ge__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__gt__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__le__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__lt__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__ne__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__repr__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__str__
   :noindex:
